@@ -1,7 +1,7 @@
 #*********************************************************************
 #*** ResourcePool::Factory
 #*** Copyright (c) 2002,2003 by Markus Winand <mws@fatalmind.com>
-#*** $Id: Factory.pm,v 1.33 2009-11-25 14:40:22 mws Exp $
+#*** $Id: Factory.pm,v 1.34 2013-04-16 10:14:44 mws Exp $
 #*********************************************************************
 
 package ResourcePool::Factory;
@@ -13,7 +13,7 @@ use ResourcePool::Resource;
 use Data::Dumper;
 
 push @ISA, "ResourcePool::Singleton";
-$VERSION = "1.0106";
+$VERSION = "1.0107";
 
 ####
 # Some notes about the singleton behavior of this class.
@@ -68,6 +68,11 @@ sub mk_singleton_key($) {
 	my $d = Data::Dumper->new([$_[0]]);
 	$d->Indent(0);
 	$d->Terse(1);
+
+	# Required to get stable results in presence of sort key randomization
+	# See https://rt.cpan.org/Public/Bug/Display.html?id=84265
+	$d->Sortkeys(1);
+
 	return $d->Dump();
 }
 
